"use strict";
module.exports = {
    extends: ['./javascript'],
    overrides: [
        {
            files: ['**/*.ts', '**/*.tsx'],
            parser: '@typescript-eslint/parser',
            parserOptions: {
                sourceType: 'module',
                ecmaFeatures: {
                    jsx: true,
                },
                warnOnUnsupportedTypeScriptVersion: false,
            },
            extends: ['standard', 'prettier', 'plugin:prettier/recommended', 'plugin:@typescript-eslint/recommended'],
            plugins: ['prettier', '@typescript-eslint', '@stylistic'],
            rules: {
                // TypeScript's `noFallthroughCasesInSwitch` option is more robust (#6906)
                'default-case': 'off',
                // 'tsc' already handles this (https://github.com/typescript-eslint/typescript-eslint/issues/291)
                'no-dupe-class-members': 'off',
                // 'tsc' already handles this (https://github.com/typescript-eslint/typescript-eslint/issues/477)
                'no-undef': 'off',
                // Add TypeScript specific rules (and turn off ESLint equivalents)
                '@typescript-eslint/consistent-type-assertions': 'warn',
                'no-array-constructor': 'off',
                '@typescript-eslint/no-array-constructor': 'warn',
                '@typescript-eslint/no-namespace': 'error',
                'no-use-before-define': 'off',
                '@typescript-eslint/no-use-before-define': [
                    'error',
                    {
                        functions: false,
                        classes: false,
                        variables: false,
                        typedefs: false,
                    },
                ],
                'no-unused-vars': 'off',
                '@typescript-eslint/no-unused-vars': [
                    'error',
                    {
                        // args: 'none',
                        // ignoreRestSiblings: true,
                        caughtErrors: 'none',
                    },
                ],
                'no-useless-constructor': 'off',
                '@typescript-eslint/no-useless-constructor': 'warn',
                'prettier/prettier': 'error',
                'standard/no-callback-literal': 'off',
                '@typescript-eslint/explicit-function-return-type': 'off',
                '@typescript-eslint/explicit-module-boundary-types': 'off',
                '@typescript-eslint/member-delimiter-style': 'off',
                '@typescript-eslint/no-explicit-any': 'off',
                quotes: 'off',
                '@stylistic/quotes': [
                    'error',
                    'single',
                    {
                        avoidEscape: true,
                        allowTemplateLiterals: false,
                    },
                ],
            },
        },
    ],
};
